@@ -1,8 +1,10 @@
 package Devel::ebug::HTTP;
+
 use strict;
 use warnings;
-use Catalyst qw/Static/;
-#use Catalyst qw/-Debug Static/;
+use 5.010001;
+use Catalyst qw/Static::Simple/;
+#use Catalyst qw/-Debug Static::Simple/;
 use Catalyst::View::TT;
 use Cwd;
 use Devel::ebug;
@@ -12,9 +14,12 @@ use Path::Class;
 use PPI;
 use PPI::HTML;
 use Storable qw(dclone);
-our $VERSION = "0.32";
+use File::ShareDir::Dist qw( dist_share );
 
-# globals for now, sigh
+# ABSTRACT: A web front end to a simple, extensible Perl debugger
+our $VERSION = '0.33'; # VERSION
+
+# global for now, sigh
 my $codelines_cache;
 our $ebug;
 my $lines_visible_above_count = 10;
@@ -26,20 +31,19 @@ Devel::ebug::HTTP->config(
   name => 'Devel::ebug::HTTP',
 );
 
-# Catalyst has new template bundling code, but the following is
-# necessary for now as our distribution is Devel::ebug but the
-# application is Devel::ebug::HTTP (sigh)
-my $root = Devel::ebug::HTTP->config->{root};
-unless (-d $root) {
-  my $home = Devel::ebug::HTTP->config->{home};
-  $home = dir($home)->parent;
-  $root = dir($home)->subdir('root');
-  unless (-d $root) {
-    $root = dir($home)->parent->parent->parent->subdir('root');
+{
+  my $share = dist_share('Devel-ebug-HTTP');
+  
+  unless(defined $share)
+  {
+    $share = -f "share/root/index"  # TODO do relative to ebug?
+      ? "share"
+      : die "unable to find home or root";
   }
+
   Devel::ebug::HTTP->config(
-    home => $home,
-    root => $root,
+    home => "$share",
+    root => "$share/root",
   );
 }
 
@@ -77,30 +81,6 @@ sub ajax_eval : Regex('^ajax_eval$') {
   $context->response->output($result);
 }
 
-sub css : Regex('(?i)\.(?:css)') {
-  my($self, $c) = @_;
-  $c->res->headers->header('Cache-Control' => 'max-age=60');
-  $c->serve_static("text/css");
-}
-
-sub js : Regex('(?i)\.(?:js)') {
-   my($self, $c) = @_;
-   $c->res->headers->header('Cache-Control' => 'max-age=60');
-   $c->serve_static("application/x-javascript");
-}
-
-sub ico : Regex('(?i)\.(?:ico)') {
-  my($self, $c) = @_;
-  $c->res->headers->header('Cache-Control' => 'max-age=60');
-  $c->serve_static("image/vnd.microsoft.icon");
-}
-
-sub images : Regex('(?i)\.(?:gif|jpg|png)') {
-  my($self, $c) = @_;
-  $c->res->headers->header('Cache-Control' => 'max-age=60');
-  $c->serve_static;
-}
-
 sub end : Private {
   my($self, $c) = @_;
   if ($c->stash->{template}) {
@@ -235,9 +215,9 @@ sub codelines {
   # make us slightly more XHTML
   $_ =~ s{<br>}{<br/>} foreach @lines;
 
-  # link module names to search.cpan.org
+  # link module names to metacpan
   @lines = map {
-    $_ =~ s{<span class="word">([^<]+?::[^<]+?)</span>}{<span class="word"><a href="http://search.cpan.org/perldoc?$1">$1</a></span>};
+    $_ =~ s{<span class="word">([^<]+?::[^<]+?)</span>}{<span class="word"><a href="https://metacpan.org/pod/$1">$1</a></span>};
     $_;
   } @lines;
 
@@ -251,18 +231,26 @@ sub variable_html {
 }
 
 sub line_html {
-	my($url, $line) = @_;
-	return qq{<a href="#" style="text-decoration: none" onClick="return break_point($line)">$line</a>};
+  my($url, $line) = @_;
+  return qq{<a href="#" style="text-decoration: none" onClick="return break_point($line)">$line</a>};
 }
 
 1;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Devel::ebug::HTTP - A web front end to a simple, extensible Perl debugger
 
+=head1 VERSION
+
+version 0.33
+
 =head1 SYNOPSIS
 
   ebug_http calc.pl
@@ -282,13 +270,15 @@ L<Devel::ebug>, L<ebug_http>
 
 =head1 AUTHOR
 
-Leon Brocard, C<< <acme@astray.com> >>
+Original author: Leon Brocard E<lt>acme@astray.comE<gt>
 
-=head1 COPYRIGHT
+Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
-Copyright (C) 2005, Leon Brocard
+=head1 COPYRIGHT AND LICENSE
 
-=head1 LICENSE
+This software is copyright (c) 2005-2021 by Leon Brocard.
 
-This module is free software; you can redistribute it or modify it
-under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
